import getLog from './get-log';

const connect = async (pool, {
  MySQL,
  escapeId,
  escape
}, config) => {
  var _eventsTableName, _snapshotsTableName, _secretsTableName, _subscribersTableName;

  const log = getLog('connect');
  log.debug('connecting to mysql databases');
  Object.assign(pool, {
    escapeId,
    escape
  });
  let {
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    subscribersTableName,
    database,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = config;
  eventsTableName = (_eventsTableName = eventsTableName) !== null && _eventsTableName !== void 0 ? _eventsTableName : 'events';
  snapshotsTableName = (_snapshotsTableName = snapshotsTableName) !== null && _snapshotsTableName !== void 0 ? _snapshotsTableName : 'snapshots';
  secretsTableName = (_secretsTableName = secretsTableName) !== null && _secretsTableName !== void 0 ? _secretsTableName : 'secrets';
  subscribersTableName = (_subscribersTableName = subscribersTableName) !== null && _subscribersTableName !== void 0 ? _subscribersTableName : 'subscribers';
  log.debug(`establishing connection`);
  const connection = await MySQL.createConnection({ ...connectionOptions,
    database,
    multipleStatements: true
  });
  const [[{
    version
  }]] = await connection.query(`SELECT version() AS \`version\``);
  const major = +version.split('.')[0];

  if (isNaN(major) || major < 8) {
    throw new Error(`Supported MySQL version 8+, but got ${version}`);
  }

  log.debug(`connected successfully`);
  Object.assign(pool, {
    connection,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    subscribersTableName,
    database
  });
  log.debug('mysql databases are connected');
};

export default connect;
//# sourceMappingURL=connect.js.map