import { EventstoreResourceNotExistError } from '@resolve-js/eventstore-base';
import getLog from './get-log';
import { isNotExistError } from './resource-errors';
import executeSequence from './execute-sequence';

const dropSecrets = async pool => {
  const log = getLog('dropSecrets');
  const {
    secretsTableName,
    connection,
    database,
    escapeId
  } = pool;
  log.debug(`dropping secrets`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const statements = [`DROP TABLE ${secretsTableNameAsId}`];
  const errors = await executeSequence(connection, statements, log, error => {
    if (isNotExistError(error)) {
      return new EventstoreResourceNotExistError(`mysql adapter for database "${database}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping secrets`);
  return errors;
};

export default dropSecrets;
//# sourceMappingURL=drop-secrets.js.map