"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _getLog = _interopRequireDefault(require("./get-log"));

var _resourceErrors = require("./resource-errors");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dropSecrets = async pool => {
  const log = (0, _getLog.default)('dropSecrets');
  const {
    secretsTableName,
    connection,
    database,
    escapeId
  } = pool;
  log.debug(`dropping secrets`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const statements = [`DROP TABLE ${secretsTableNameAsId}`];
  const errors = await (0, _executeSequence.default)(connection, statements, log, error => {
    if ((0, _resourceErrors.isNotExistError)(error)) {
      return new _eventstoreBase.EventstoreResourceNotExistError(`mysql adapter for database "${database}" already dropped`);
    }

    return null;
  });
  log.debug(`finished dropping secrets`);
  return errors;
};

var _default = dropSecrets;
exports.default = _default;
//# sourceMappingURL=drop-secrets.js.map