"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _getLog = _interopRequireDefault(require("./get-log"));

var _constants = require("./constants");

var _resourceErrors = require("./resource-errors");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initEvents = async pool => {
  const log = (0, _getLog.default)('initEvents');
  log.debug('initializing events tables');
  const {
    eventsTableName,
    snapshotsTableName,
    subscribersTableName,
    escapeId,
    connection,
    database
  } = pool;
  const eventsTableNameAsId = escapeId(eventsTableName);
  const threadsTableNameAsId = escapeId(`${eventsTableName}-threads`);
  const snapshotsTableNameAsId = escapeId(snapshotsTableName);
  const subscribersTableNameAsId = escapeId(subscribersTableName);
  const statements = [`CREATE TABLE ${eventsTableNameAsId}(
      \`threadId\` ${_constants.longNumberSqlType},
      \`threadCounter\` ${_constants.longNumberSqlType},
      \`timestamp\` ${_constants.longNumberSqlType},
      \`aggregateId\` ${_constants.aggregateIdSqlType},
      \`aggregateVersion\` ${_constants.longNumberSqlType},
      \`type\` ${_constants.longStringSqlType},
      \`payload\` ${_constants.customObjectSqlType},
      PRIMARY KEY(\`threadId\`, \`threadCounter\`),
      UNIQUE KEY \`aggregate\`(\`aggregateId\`, \`aggregateVersion\`),
      INDEX USING BTREE(\`aggregateId\`),
      INDEX USING BTREE(\`aggregateVersion\`),
      INDEX USING BTREE(\`type\`),
      INDEX USING BTREE(\`timestamp\`)
    )`, `CREATE TABLE ${threadsTableNameAsId}(
      \`threadId\` ${_constants.longNumberSqlType},
      \`threadCounter\` ${_constants.longNumberSqlType},
      PRIMARY KEY(\`threadId\`)
    )`, `CREATE TABLE ${snapshotsTableNameAsId} (
      \`SnapshotKey\` ${_constants.mediumBlobSqlType},
      \`SnapshotContent\` ${_constants.longBlobSqlType},
      PRIMARY KEY(\`SnapshotKey\`(255))
    )`, `INSERT INTO ${threadsTableNameAsId}(
      \`threadId\`,
      \`threadCounter\`
    ) VALUES ${Array.from(new Array(256)).map((_, index) => `(${index}, 0)`).join(',')}`, `CREATE TABLE ${subscribersTableNameAsId} (
      \`applicationName\` ${_constants.longStringSqlType},
      \`eventSubscriber\` ${_constants.longStringSqlType},
      \`destination\` ${_constants.customObjectSqlType},
      \`status\` ${_constants.customObjectSqlType},
      PRIMARY KEY(\`applicationName\`(127), \`eventSubscriber\`(127))
    )`];
  const errors = await (0, _executeSequence.default)(connection, statements, log, error => {
    if ((0, _resourceErrors.isAlreadyExistsError)(error)) {
      return new _eventstoreBase.EventstoreResourceAlreadyExistError(`duplicate initialization of the mysql adapter with same event database "${database}" and table "${eventsTableName}" is not allowed`);
    }

    return null;
  });
  log.debug('finished initializing events tables');
  return errors;
};

var _default = initEvents;
exports.default = _default;
//# sourceMappingURL=init-events.js.map