"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _getLog = _interopRequireDefault(require("./get-log"));

var _constants = require("./constants");

var _resourceErrors = require("./resource-errors");

var _executeSequence = _interopRequireDefault(require("./execute-sequence"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initSecrets = async pool => {
  const log = (0, _getLog.default)('initSecrets');
  log.debug('initializing secrets table');
  const {
    secretsTableName,
    escapeId,
    connection,
    database
  } = pool;
  const secretsTableNameAsId = escapeId(secretsTableName);
  const statements = [`CREATE TABLE ${secretsTableNameAsId}(
      \`idx\` ${_constants.longNumberSqlType},
      \`id\` ${_constants.aggregateIdSqlType},
      \`secret\` ${_constants.longStringSqlType},
      PRIMARY KEY(\`id\`, \`idx\`)
    )`];
  const errors = await (0, _executeSequence.default)(connection, statements, log, error => {
    if ((0, _resourceErrors.isAlreadyExistsError)(error)) {
      return new _eventstoreBase.EventstoreResourceAlreadyExistError(`duplicate initialization of the mysql adapter with the same event database "${database}" and table "${secretsTableName}" is not allowed`);
    }

    return null;
  });
  log.debug('finished initializing secrets table');
  return errors;
};

var _default = initSecrets;
exports.default = _default;
//# sourceMappingURL=init-secrets.js.map