"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _constants = require("./constants");

const saveEvent = async (pool, event) => {
  const {
    eventsTableName,
    connection,
    database,
    escapeId,
    escape
  } = pool;

  try {
    const eventsTableNameAsId = escapeId(eventsTableName);
    const freezeTableNameAsString = escape(`${eventsTableName}-freeze`);
    const threadsTableNameAsId = escapeId(`${eventsTableName}-threads`);
    const databaseNameAsString = escape(database);
    const serializedPayload = event.payload != null ? escape(JSON.stringify(event.payload)) : escape('null'); // prettier-ignore

    await connection.query(`START TRANSACTION;
      SELECT 1 FROM \`information_schema\`.\`tables\`
      WHERE (
         SELECT 0 AS \`EventStoreIsFrozen\`
       UNION ALL
          SELECT 0 AS \`EventStoreIsFrozen\`
          FROM \`information_schema\`.\`tables\` \`INF\`
          WHERE \`INF\`.\`table_schema\` = ${databaseNameAsString}
          AND \`INF\`.\`table_name\` = ${freezeTableNameAsString}
       ) = 0;
       
      SET @selectedThreadId = FLOOR(RAND() * 256);
      
      SELECT @threadCounter := \`threadCounter\`
      FROM ${threadsTableNameAsId}
      WHERE \`threadId\` = @selectedThreadId
      FOR UPDATE;
      
      UPDATE ${threadsTableNameAsId}
      SET \`threadCounter\` = \`threadCounter\` + 1
      WHERE \`threadId\` = @selectedThreadId;
      
      INSERT INTO ${eventsTableNameAsId}(
        \`threadId\`,
        \`threadCounter\`,
        \`timestamp\`,
        \`aggregateId\`,
        \`aggregateVersion\`,
        \`type\`,
        \`payload\`
      ) VALUES(
        @selectedThreadId,
        COALESCE(@threadCounter, 0),
        GREATEST(
          ROUND(UNIX_TIMESTAMP(SYSDATE(4)) * 1000),
          ${+event.timestamp}
        ),
        ${escape(event.aggregateId)},
        ${+event.aggregateVersion},
        ${escape(event.type)},
        (CAST(${serializedPayload} AS JSON))
      );
      
      COMMIT;`);
  } catch (error) {
    const errno = error != null && error.errno != null ? error.errno : 0;
    const message = error != null && error.message != null ? error.message : '';

    try {
      await connection.query('ROLLBACK;');
    } catch (e) {}

    if (errno === _constants.ER_SUBQUERY_NO_1_ROW) {
      throw new Error('Event store is frozen');
    } else if (errno === _constants.ER_DUP_ENTRY && message.indexOf('aggregate') > -1) {
      throw new _eventstoreBase.ConcurrentError(event.aggregateId);
    } else if (errno === _constants.ER_DUP_ENTRY && message.indexOf('PRIMARY') > -1 || errno === _constants.ER_LOCK_DEADLOCK) {
      return await saveEvent(pool, event);
    } else {
      throw error;
    }
  }
};

var _default = saveEvent;
exports.default = _default;
//# sourceMappingURL=save-event.js.map