"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setSecret = async (pool, selector, secret) => {
  const log = (0, _getLog.default)('secretsManager:setSecret');
  log.debug(`setting secret value within database`);
  const {
    secretsTableName,
    connection,
    escape,
    escapeId
  } = pool;
  log.verbose(`selector: ${selector}`);
  log.verbose(`tableName: ${secretsTableName}`);
  const tableId = escapeId(secretsTableName); // prettier-ignore

  const query = `START TRANSACTION;
     
      SELECT @idx := COALESCE(MAX(\`idx\`) + 1, 0) FROM ${tableId};
      
      INSERT INTO ${tableId}(
       \`idx\`,
       \`id\`, 
       \`secret\`
       ) VALUES(
        @idx,
        ${escape(selector)},
        ${escape(secret)}
      );
      
      COMMIT;`;
  log.verbose(`SQL query verbose output hidden due to security reasons`);

  try {
    log.debug(`executing SQL query`);
    await connection.query(query);
    log.debug(`query executed successfully`);
  } catch (error) {
    log.error(error.message);
    log.verbose(error.stack);

    try {
      log.debug(`rolling back`);
      await connection.query('ROLLBACK;');
    } catch (e) {
      log.error(e.message);
      log.verbose(e.stack);
    }

    throw error;
  }
};

var _default = setSecret;
exports.default = _default;
//# sourceMappingURL=set-secret.js.map